.. _release-0-8-2:

0.8.2
=====

Bokeh ``0.8.2`` (Mar 2015) is a quick release focused on some refactoring,
bug fixes and improved documentation.

* Collect implicit interfaces into a single bokeh.io module
* Fixed notebook css issues
* Update notebooks to be compatible with IPython 3.0
* Easy bokeh applet generation using the simpleapp module
* Develop installation enhancements
* A new User guide intro and some other docs styling enhancements
* Some other minor examples bugfixes
